#!/usr/bin/bash
#################################################################
#	Complete MSM Package installation script		#
#################################################################

usage()
{
 	echo "Incorrect option selected. Please retry....."
        echo "This mode of installation is not supported for MegaRAIDStorageManager"
        echo "usage: "./install.sh""
	
}

uninstall_old_msm()
{
	echo "A version of MegaRAID Storage Manager is found on this system."

	echo "Uninstalling the existing version of MegaRAID Storage Manager."

	/opt/MegaRaidStorageManager/uninstaller.sh

	if [ $? -ne 0 ]; then

		echo "Installation of MegaRAID Storage Manager got aborted as the uninstallation of existing version of Mega RAID Storage Manager failed."
	
		exit 1;

	fi

	echo "Uninstallation of previous package got completed."

	sleep 20
	echo "";
	echo "";
	echo "";
	echo "";
	echo "";
	echo "";

	sleep 20
	echo "";
	echo "";
	echo "";
	echo "";
	echo "";

	sleep 20
}

if [ $# == 0 ]; then
	
	# If user executes install.sh without any
	# arguments then default is full installation.

	echo "Starting complete installation of MegaRAID Storage Manager"

fi

if [ $# = 1 ]; then
		 usage
                exit 0;

fi

PKGNAME=MegaRaidStorageManager	
PKGFILE=""
CURVER=`/usr/bin/pkginfo -l ${PKGNAME} 2>&1 | grep "VERSION:" | awk '{ print $2 }' | cut -f1 -d"-"`

PKGFILE=$PKGNAME-*.pkg
UPDATEVER=`/usr/bin/pkginfo -l -d ${PKGFILE} 2>&1 | grep "VERSION:" | awk '{ print $2 }' | cut -f1 -d "-"`

/usr/bin/pkginfo -ql ${PKGNAME} 2>/dev/null

if [ $? -ne 1 ]; then

	if [ "${CURVER}" = "${UPDATEVER}" ]; then

		installedMinorVer=`/usr/bin/pkginfo -l ${PKGNAME} 2>&1 | grep "VERSION:" | awk '{ print $2 }' | cut -f2 -d"-"`

		updatingMinorVer=`/usr/bin/pkginfo -l -d ${PKGFILE} 2>&1 | grep "VERSION:" | awk '{ print $2 }' | cut -f2 -d "-"`

		if [ "${installedMinorVer}" = "${updatingMinorVer}" ]; then
	
			 echo "The version of package you are trying to install is already installed on this machine."
		
			exit 0

		elif expr "${installedMinorVer}" \> "${updatingMinorVer}" 2>/dev/null >/dev/null
		then

			echo "The version of MegaRAID Storage Manager that is installed in this system is higher than the version you are trying to install."

			echo "Please uninstall the existing version before proceeding with the current installation."

			exit 1;

		elif expr "${installedMinorVer}" \< "${updatingMinorVer}" 2>/dev/null >/dev/null
		then
			uninstall_old_msm;
		fi

	elif expr "${CURVER}" \> "${UPDATEVER}" 2>/dev/null >/dev/null
	then

		echo "The version of MegaRAID Storage Manager that is installed in this system is higher than the version you are trying to install."

		echo "Please uninstall the existing version before proceeding with the current installation."

		exit 1;

	elif expr "${CURVER}" \< "${UPDATEVER}" 2>/dev/null >/dev/null
	then
		uninstall_old_msm;
	fi
fi


INSTALL_LOG="/tmp/lsi_install.log"
install_pkg()
{
	PKGNAME=$1	
	PKGFILE=""
	CURVER=`/usr/bin/pkginfo -l ${PKGNAME} 2>&1 | grep "VERSION:" | awk '{ print $2 }'`
	if [ -f $1-*.pkg ] ; then
		PKGFILE=$1-*.pkg
	elif [ $1 = "MegaCli" ] ; then
		PKGFILE=$1.pkg
	fi

	if [ "${PKGFILE}" = "" ]; then
		echo "Couldn't find an appropriate installation package for $1"
		exit 1	
	else
		UPDATEVER=`/usr/bin/pkginfo -l -d ${PKGFILE} 2>&1 | grep "VERSION:" | awk '{ print $2 }'`		
		TEST_VER=`echo $UPDATEVER " " $CURVER | awk '$1==$2 {print "TRUE"}'`	
		echo "Installing ${PKGNAME} Ver ${UPDATEVER} : "  	
		if [ "${TEST_VER}" = "TRUE" ] ; then
			echo " [ Already Installed ] "
			return 0
		fi

		if [ "${CURVER}" != "" ]  ; then
			echo "${PKGNAME} ver ${CURVER} is already installed"
			echo "Please uninstall existing ${PKGNAME} and continue installation"
			echo "Exiting..."
			exit 1	
		
		else	
			if [ "${PKGFILE}" = "MegaCli.pkg" ] ; then
				pkgadd -d ${PKGFILE} SOLMEGACLI
				if [ $? -ne 0 ] ; then
					echo " [ Installation Failed ] "
				else	
					echo " [ Installation Ok ] "
				fi
			else
				pkgadd -d ${PKGFILE} ${PKGNAME} 
				if [ $? -ne 0 ] ; then
					echo " [ Installation Failed ] "
				else
					echo " [ Installation Ok ] "
				fi
			fi
							
		fi		
	fi

}

INSTALL_LIST="MegaRaidStorageManager sassnmp sasirsnmp"

if [ "$1" = "-c" ]; then
	INSTALL_LIST="MegaRaidStorageManager"

fi

for i in ${INSTALL_LIST}
do
	install_pkg $i
done

if [ -d "/opt/MegaRaidStorageManager" ]; then

	if [ "$1" = "-s" ]; then

		echo "Remove the Network capability plugin from the Framework";
		#svcadm disable -t MSMMonitor
		#sleep 10
		svcadm disable -t MSMFramework

		rm -rf /opt/MegaRaidStorageManager/Framework/plugins/NetworkCapabilityPlugin.class

		svcadm enable MSMFramework
		#sleep 3
		#svcadm enable MSMMonitor
	fi

	if [ "$1" = "-c" ]; then
	
		#svcadm disable -t MSMMonitor
		#sleep 5
		svcadm disable -t MSMFramework

		#svcadm disable MSMMonitor
		#sleep 3
		svcadm disable MSMFramework
		sleep 3

		#svccfg delete -f MSMMonitor
		svccfg delete -f MSMFramework

		rm -rf /opt/MegaRaidStorageManager/Framework
		rm -rf /opt/MegaRaidStorageManager/MegaMonitor
		rm -rf /opt/MegaRaidStorageManager/MegaPopup
		rm -rf /opt/MegaRaidStorageManager/Common

		sed 's/\/opt\/MegaRaidStorageManager\/MegaPopup\/popup&//g' /etc/profile >/etc/profile2
		mv /etc/profile2 /etc/profile

	fi

	#if [ "$1" != "-c" ]; then
	#	cd /opt/MegaRaidStorageManager/MegaPopup;
	#	./popup > /dev/null;
	#	cd - >/dev/null;
	#fi
fi

#Change the directory permission of /usr/lib so that errors
#won't popup during the boot. The problem is found to be in storelib-ir package.

chmod -R +x /usr/lib 2>/dev/null

. /opt/MegaRaidStorageManager/MegaPopup/popup&
